/***
 * Excerpted from "Using memcached: How to scale your website easily",
 * published by The Pragmatic Bookshelf.
 * Copyrights apply to this code. It may not be used to create training material, 
 * courses, books, articles, and the like. Contact us if you are in doubt.
 * We make no guarantees that this code is fit for any purpose. 
 * Visit http://www.pragmaticprogrammer.com/titles/memcd for more book information.
***/
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

using System.Net;

// MemCache
//using Memcached.ClientLibrary;  // Plans are to decrement this
using Enyim.Caching;
using Enyim.Caching.Memcached;
using Enyim.Caching.Configuration;

namespace MemcachedStatistics
{
 public partial class Form1 : Form
 {
	public Form1()
	{
	 InitializeComponent();
	 if (Properties.Settings.Default.ServerList != string.Empty)
	 {
		DataSet ds = new DataSet();
		ds.ReadXml(new System.IO.StringReader(Properties.Settings.Default.ServerList));
		foreach (DataRow dr in ds.Tables[0].Rows)
		{dgvServers.Rows.Add(dr[0].ToString(), dr[1].ToString());
		}
	 }
	}

	private void button2_Click(object sender, EventArgs e)
	{
	 if (dgvServers.Rows.Count < 1)
	 {
		MessageBox.Show("You must put in at least one memcached server/port", "Need memcached server", MessageBoxButtons.OK, MessageBoxIcon.Error);
	 }
	 else
	 {
		MemcachedClientConfiguration config = new MemcachedClientConfiguration();
		try{
		
		for (int i = 0; i < dgvServers.Rows.Count;i++ )
		{
		 
		 config.Servers.Add(new IPEndPoint( IPAddress.Parse(dgvServers.Rows[i].Cells[0].Value.ToString()), Convert.ToInt16(dgvServers.Rows[i].Cells[1].Value.ToString())));
		}
	 }
	 catch { }
	 try
	 {
		MemcachedClient mc = new MemcachedClient(config);
		ServerStats ss = mc.Stats();
		ss.GetType();
		dgvStatistics.Rows.Clear();
		dgvStatistics.Columns.Clear();
		DataGridViewTextBoxColumn tb = new DataGridViewTextBoxColumn();
		tb.HeaderText = "Data";
		tb.AutoSizeMode = DataGridViewAutoSizeColumnMode.AllCells;
		
		dgvStatistics.Columns.Add(tb);
		DataGridViewTextBoxColumn tb1 = new DataGridViewTextBoxColumn();
		tb1.HeaderText = "Type";
		tb1.AutoSizeMode = DataGridViewAutoSizeColumnMode.AllCells;
		dgvStatistics.Columns.Add(tb1);
		//dgvStatistics.Rows.Add("Uptime", ss.GetValue(ServerStats.All, StatItem.Uptime));
		dgvStatistics.Rows.Add("Bytes Read", string.Format("{0:N0}", ss.GetValue(ServerStats.All, StatItem.BytesRead)));
		dgvStatistics.Rows.Add("Bytes Written", string.Format("{0:N0}", ss.GetValue(ServerStats.All, StatItem.BytesWritten)));
		dgvStatistics.Rows.Add("Connection Count", string.Format("{0:N0}", ss.GetValue(ServerStats.All, StatItem.ConnectionCount)));
		dgvStatistics.Rows.Add("Items", string.Format("{0:N0}", ss.GetValue(ServerStats.All, StatItem.ItemCount)));
		dgvStatistics.Rows.Add("Gets", string.Format("{0:N0}", ss.GetValue(ServerStats.All, StatItem.GetCount)));
		dgvStatistics.Rows.Add("Sets", string.Format("{0:N0}", ss.GetValue(ServerStats.All, StatItem.SetCount)));
		dgvStatistics.Rows.Add("Hits", string.Format("{0:N0}", ss.GetValue(ServerStats.All, StatItem.GetHits)));
		dgvStatistics.Rows.Add("Misses", string.Format("{0:N0}", ss.GetValue(ServerStats.All, StatItem.GetMisses)));
		dgvStatistics.Rows.Add("Cache Hit Ration", string.Format("{0:F2}%", ((double)ss.GetValue(ServerStats.All, StatItem.GetHits) / (double)ss.GetValue(ServerStats.All, StatItem.GetCount) * 100)));
		tabControl1.SelectedTab = tabPage2;
	 }
	 catch (Exception ex)
	 {
		Console.Write(ex.ToString());
	 }

	 }
	}

	private void Form1_FormClosing(object sender, FormClosingEventArgs e)
	{
	 StringBuilder sb = new StringBuilder("<root>");
	 for (int i = 0; i < dgvServers.Rows.Count; i++)
	 {
		if (dgvServers.Rows[i].Cells[0].Value != null)
		 sb.AppendFormat("<ServerInfo><IPAddress>{0}</IPAddress><Port>{1}</Port></ServerInfo>", dgvServers.Rows[i].Cells[0].Value.ToString(), dgvServers.Rows[i].Cells[1].Value.ToString());
	 }
	 sb.AppendLine("</root>");
	 Properties.Settings.Default.ServerList = sb.ToString();
	 Properties.Settings.Default.Save();
	}

	private void Form1_Load(object sender, EventArgs e)
	{

	}


 }
}